@@ -29,11 +29,18 @@ from workflows.task import Task
 
 
 T = TypeVar("T")
+_DEFAULT_EXIST_OK = False
 _DEFAULT_OVERWRITE = False
+_DEFAULT_PARALLEL = False
 
 
 class FileTask(Task[T]):
-    def __call__(self: FileTask[T], *, overwrite: bool = _DEFAULT_OVERWRITE) -> T:
+    def __call__(
+        self: FileTask[T],
+        *,
+        overwrite: bool = _DEFAULT_OVERWRITE,
+        exist_ok: bool = _DEFAULT_EXIST_OK,
+    ) -> T:
         path = self.path()
         if overwrite:
             out = self.compute()
@@ -45,9 +52,16 @@ class FileTask(Task[T]):
                 return self.read(path)
             except FileNotFoundError:
                 out = self.compute()
-                with atomic_write_path(path, overwrite=False) as temp:
-                    self.write(out, temp)
-                return out
+                try:
+                    with atomic_write_path(path, overwrite=False) as temp:
+                        self.write(out, temp)
+                except FileExistsError:
+                    if exist_ok:
+                        return out
+                    else:
+                        raise
+                else:
+                    return out
 
     @abstractmethod  # noqa: U100
     def compute(self: FileTask[T]) -> T:  # noqa: U100
@@ -67,36 +81,49 @@ class FileTask(Task[T]):
 
     @classmethod
     def run(
-        cls: Type[FileTask], tasks: Iterable[FileTask], *, overwrite: bool = _DEFAULT_OVERWRITE,
+        cls: Type[FileTask],
+        tasks: Iterable[FileTask],
+        *,
+        overwrite: bool = _DEFAULT_OVERWRITE,
+        exist_ok: bool = _DEFAULT_EXIST_OK,
+        parallel: bool = _DEFAULT_PARALLEL,
     ) -> None:
         tasks: Set[FileTask] = reduce(
             or_, ({task} | task.get_dependencies(recurse=True) for task in tasks), set(),
         )
         if not overwrite:
             tasks = {task for task in tasks if not task.path().exists()}
-        futures: Dict[Task, Future] = {}
-        with ProcessPoolExecutor() as executor:
+        if parallel:
+            futures: Dict[Task, Future] = {}
+            with ProcessPoolExecutor() as executor:
+                while tasks:
+                    completed: Set[Task] = set()
+                    for task in tasks:
+                        try:
+                            future = futures[task]
+                        except KeyError:
+                            if all(
+                                dep not in tasks for dep in task.get_dependencies(recurse=True)
+                            ) and (task not in futures):
+                                futures[task] = executor.submit(
+                                    task, overwrite=overwrite, exist_ok=exist_ok,
+                                )
+                        else:
+                            if future.done():
+                                maybe_exception = future.exception()
+                                if maybe_exception is None:
+                                    completed.add(task)
+                                else:
+                                    try:
+                                        raise RunTasksError(f"Task {task} failed")
+                                    except RunTasksError as error:
+                                        raise maybe_exception from error
+                    tasks -= completed
+        else:
             while tasks:
-                completed: Set[Task] = set()
-                for task in tasks:
-                    try:
-                        future = futures[task]
-                    except KeyError:
-                        if all(
-                            dep not in tasks for dep in task.get_dependencies(recurse=True)
-                        ) and (task not in futures):
-                            futures[task] = executor.submit(task, overwrite=overwrite)
-                    else:
-                        if future.done():
-                            maybe_exception = future.exception()
-                            if maybe_exception is None:
-                                completed.add(task)
-                            else:
-                                try:
-                                    raise RunTasksError(f"Task {task} failed")
-                                except RunTasksError as error:
-                                    raise maybe_exception from error
-                tasks -= completed
+                task = next(iter(tasks))
+                task(overwrite=overwrite, exist_ok=exist_ok)
+                tasks.remove(task)
 
 
 def floor_datetime(
