@@ -3,20 +3,20 @@ from __future__ import annotations
 from abc import ABCMeta
 from abc import abstractmethod
 from functools import lru_cache
+from functools import reduce
 from functools import wraps
+from operator import or_
 from typing import Any
 from typing import cast
 from typing import Dict
 from typing import Generic
 from typing import Hashable
+from typing import Set
 from typing import Tuple
 from typing import Type
 from typing import TypeVar
 from typing import Union
 
-from functional_itertools import CDict
-from functional_itertools import CSet
-
 from workflows.errors import UnhashableParameterError
 
 
@@ -40,22 +40,22 @@ class TaskMeta(ABCMeta):
             @wraps(init)
             def __init__(self: Task, *args: Any, **kwargs: Any) -> None:
                 try:
-                    self._parameters_and_dependencies
+                    self._dependencies_and_parameters
                 except AttributeError:
-                    pre_attrs = CSet(dir(self))
+                    pre_attrs = set(dir(self))
                     init(self, *args, **kwargs)
-                    new_attrs: CDict[str, Any] = CSet(set(dir(self)) - pre_attrs).filter(
-                        lambda x: x != "_parameters_and_dependencies",
-                    ).map_dict(lambda x: getattr(self, x))
-                    parameters: CDict[str, Hashable] = new_attrs.filter_keys(
-                        lambda x: x != "_parameters_and_dependencies",
-                    ).filter_values(lambda x: not isinstance(x, Task)).map_items(
-                        lambda k, v: (k, self._check_hashable(k, v)),
-                    )
-                    dependencies: CSet[Task] = new_attrs.values().set().filter(
-                        lambda x: isinstance(x, Task),
-                    )
-                    self._parameters_and_dependencies = (parameters, dependencies)
+                    new_attrs: Dict[str, Any] = {
+                        attr: getattr(self, attr)
+                        for attr in set(dir(self)) - pre_attrs
+                        if attr != "_dependencies_and_parameters"
+                    }
+                    dependencies: Set[Task] = {x for x in new_attrs.values() if isinstance(x, Task)}
+                    parameters: Dict[str, Hashable] = {
+                        k: self._check_hashable(k, v)
+                        for k, v in new_attrs.items()
+                        if not isinstance(v, Task)
+                    }
+                    self._dependencies_and_parameters = (dependencies, parameters)
                 else:
                     init(self, *args, **kwargs)
                 for key, value in self.get_parameters().items():
@@ -80,35 +80,34 @@ class Task(Generic[T], metaclass=TaskMeta):
     def __hash__(self: Task[T]) -> int:
         return hash(frozenset(self.get_parameters().items()))
 
-    def get_parameters(self: Task[T]) -> CDict[str, Hashable]:
-        try:
-            parameters, _ = self._parameters_and_dependencies
-        except AttributeError:
-            return CDict()
-        else:
-            return parameters
-
     @lru_cache()
-    def get_dependencies(self: Task[T], *, recurse: bool = False) -> CSet[Task]:
+    def get_dependencies(self: Task[T], *, recurse: bool = False) -> Set[Task]:
         if recurse:
             dependencies = self.get_dependencies(recurse=False)
             while True:
-                expanded = dependencies.reduce(
-                    lambda x, y: x.chain([y]).chain(y.get_dependencies(recurse=False)),
-                    initial=CSet(),
+                expanded = dependencies | set(
+                    reduce(or_, (x.get_dependencies(recurse=False) for x in dependencies), set()),
                 )
                 if expanded.issubset(dependencies):
                     return dependencies
                 else:
-                    dependencies = CSet(dependencies | expanded)
+                    dependencies = dependencies | expanded
         else:
             try:
-                _, dependencies = self._parameters_and_dependencies
+                dependencies, _ = self._dependencies_and_parameters
             except AttributeError:
-                return CSet()
+                return set()
             else:
                 return dependencies
 
+    def get_parameters(self: Task[T]) -> Dict[str, Hashable]:
+        try:
+            _, parameters = self._dependencies_and_parameters
+        except AttributeError:
+            return {}
+        else:
+            return parameters
+
     @classmethod
     def _check_hashable(cls: Type[Task], key: str, value: Any) -> Hashable:
         try:
